.. PyStan documentation master file, created by
   sphinx-quickstart on Fri May 24 13:36:04 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyStan: The Python Interface to Stan
====================================

PyStan provides an interface to `Stan <http://mc-stan.org>`_, a package for
Bayesian inference using the No-U-Turn sampler, a variant of Hamiltonian Monte
Carlo.

License: Open source, GPL3

Documentation
-------------

.. toctree::
   :maxdepth: 1

   getting_started
   optimizing
   differences_pystan_and_rstan
   whats_new
   api

Stan documentation
------------------

- Stan: http://mc-stan.org/
- `Stan User's Guide and Reference Manual <http://stan.googlecode.com/files/stan-reference-1.3.0.pdf>`_
- `BUGS Examples <https://github.com/stan-dev/stan/tree/master/src/models/bugs_examples>`_

Important links
---------------

- Source code repo: https://github.com/ariddell/pystan
- HTML documentation: http://pystan.readthedocs.org
- Issue tracker: https://github.com/ariddell/pystan/issues

Similar projects
----------------

- PyMC: http://pymc-devs.github.io/pymc/

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

